Class CreateRegisterCodeRequest
- java.lang.Object
-
- com.tencentcloudapi.common.AbstractModel
-
- com.tencentcloudapi.tat.v20201028.models.CreateRegisterCodeRequest
-
public class CreateRegisterCodeRequest extends AbstractModel
-
-
Field Summary
-
Fields inherited from class com.tencentcloudapi.common.AbstractModel
header, skipSign
-
-
Constructor Summary
Constructors Constructor Description CreateRegisterCodeRequest()CreateRegisterCodeRequest(CreateRegisterCodeRequest source)NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy, and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description StringgetDescription()Get 注册码描述。LonggetEffectiveTime()Get 该注册码的有效时间,单位为小时。默认为4小时。StringgetInstanceNamePrefix()Get 注册实列名称前缀。StringgetIpAddressRange()Get 该注册码限制tat_agent只能从IpAddressRange所描述公网出口进行注册。默认不做限制。LonggetRegisterLimit()Get 该注册码允许注册的实列数目。默认限制为10个。voidsetDescription(String Description)Set 注册码描述。voidsetEffectiveTime(Long EffectiveTime)Set 该注册码的有效时间,单位为小时。默认为4小时。voidsetInstanceNamePrefix(String InstanceNamePrefix)Set 注册实列名称前缀。voidsetIpAddressRange(String IpAddressRange)Set 该注册码限制tat_agent只能从IpAddressRange所描述公网出口进行注册。默认不做限制。voidsetRegisterLimit(Long RegisterLimit)Set 该注册码允许注册的实列数目。默认限制为10个。voidtoMap(HashMap<String,String> map, String prefix)Internal implementation, normal users should not use it.-
Methods inherited from class com.tencentcloudapi.common.AbstractModel
any, fromJsonString, getBinaryParams, GetHeader, getMultipartRequestParams, getSkipSign, set, SetHeader, setParamArrayObj, setParamArraySimple, setParamObj, setParamSimple, setSkipSign, toJsonString
-
-
-
-
Constructor Detail
-
CreateRegisterCodeRequest
public CreateRegisterCodeRequest()
-
CreateRegisterCodeRequest
public CreateRegisterCodeRequest(CreateRegisterCodeRequest source)
NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy, and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
-
-
Method Detail
-
getDescription
public String getDescription()
Get 注册码描述。- Returns:
- Description 注册码描述。
-
setDescription
public void setDescription(String Description)
Set 注册码描述。- Parameters:
Description- 注册码描述。
-
getInstanceNamePrefix
public String getInstanceNamePrefix()
Get 注册实列名称前缀。- Returns:
- InstanceNamePrefix 注册实列名称前缀。
-
setInstanceNamePrefix
public void setInstanceNamePrefix(String InstanceNamePrefix)
Set 注册实列名称前缀。- Parameters:
InstanceNamePrefix- 注册实列名称前缀。
-
getRegisterLimit
public Long getRegisterLimit()
Get 该注册码允许注册的实列数目。默认限制为10个。- Returns:
- RegisterLimit 该注册码允许注册的实列数目。默认限制为10个。
-
setRegisterLimit
public void setRegisterLimit(Long RegisterLimit)
Set 该注册码允许注册的实列数目。默认限制为10个。- Parameters:
RegisterLimit- 该注册码允许注册的实列数目。默认限制为10个。
-
getEffectiveTime
public Long getEffectiveTime()
Get 该注册码的有效时间,单位为小时。默认为4小时。- Returns:
- EffectiveTime 该注册码的有效时间,单位为小时。默认为4小时。
-
setEffectiveTime
public void setEffectiveTime(Long EffectiveTime)
Set 该注册码的有效时间,单位为小时。默认为4小时。- Parameters:
EffectiveTime- 该注册码的有效时间,单位为小时。默认为4小时。
-
getIpAddressRange
public String getIpAddressRange()
Get 该注册码限制tat_agent只能从IpAddressRange所描述公网出口进行注册。默认不做限制。- Returns:
- IpAddressRange 该注册码限制tat_agent只能从IpAddressRange所描述公网出口进行注册。默认不做限制。
-
setIpAddressRange
public void setIpAddressRange(String IpAddressRange)
Set 该注册码限制tat_agent只能从IpAddressRange所描述公网出口进行注册。默认不做限制。- Parameters:
IpAddressRange- 该注册码限制tat_agent只能从IpAddressRange所描述公网出口进行注册。默认不做限制。
-
-